/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.processors;

import org.wso2.registry.Registry;
import org.wso2.registry.Resource;
import org.wso2.registry.exceptions.RegistryException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Iterator;

public class ResourceCreationUIProcessor extends UIProcessor {

    public void process(HttpServletRequest request, HttpServletResponse response) {

        String mediaType = request.getParameter("mediaType");
        String parentPath = request.getParameter("parentPath");
        String viewName = request.getParameter("viewName");
        String resourcePath;
        if (viewName == null || viewName.equals("")) {
            resourcePath =
                    "/newPath;new:default;mediaType:" + mediaType + ";parentPath:" + parentPath;
        } else {
            resourcePath = "/newPath;new:" + viewName +
                    ";mediaType:" + mediaType + ";parentPath:" + parentPath;
        }

        try {
            Registry registry = getUserRegistry(request);
            Resource resource = registry.get(resourcePath);
            String contentCreationUI = (String) resource.getContent();
            String resourceCreationUI =
                    generateViewNamesArea(mediaType, parentPath, resource) + contentCreationUI;
            sendContent(response, resourceCreationUI);

            resource.discard();

        } catch (RegistryException e) {

            String msg = "Failed to generate resource creation UI for media type: " +
                    mediaType + ". " + e.getMessage();
            log.error(msg, e);
            sendErrorContent(response, msg);
        }
    }

    private String generateViewNamesArea(String mediaType, String parentPath, Resource resource) {

        String viewNamesArea = "<strong>Available views</strong><br/>";
        List <String> newViewName = resource.getPropertyValues("registry.new-views");
        Iterator <String> iViews = newViewName.iterator();
        while (iViews.hasNext()) {
            String viewDetail = iViews.next();
            String[] viewParts = viewDetail.split(":");
            String viewLink = "<a onclick=\"generateNewUIView('" + mediaType + "', '" +
                    viewParts[0] + "', '" + parentPath + "')\">" + viewParts[1] + "</a><br/>";
            viewNamesArea = viewNamesArea + viewLink;
        }

        viewNamesArea = viewNamesArea + "<br/>";
        return viewNamesArea;
    }
}
